<?php
/*
Plugin Name: WP-Infobox
Plugin URI: http://jonasnordstrom.se/wordpress-plugins
Description: Add an info box to posts.
Version: 0.2
Author: Jonas Nordstrom
Author URI: http://jonasnordstrom.se 
*/

/*  Copyright 2010  Jonas Nordstrom  (email : jonas.nordstrom@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


if (!class_exists("WPInfobox")) {
	class wpinfobox {
		
		// Max number of items
		protected $max_items;
		
		// Constructor
		public function WPInfobox() {
			// This should really be set as a plugin option. TODO
			$this->max_items = 7;
		}

		// initialization, setup localization
		public function init_wpinfobox() {
			// Set up localization
			$plugin_dir = basename(dirname(__FILE__)); 
			load_plugin_textdomain( 'wpinfobox', 'wp-content/plugins/'. $plugin_dir.'/languages', $plugin_dir.'/languages' );
		}
		
		// A meta box is added to "write post", in main column
		// TODO: Option to set this for post and/or pages (or other post types)
		public function add_meta_box() {
			add_meta_box('wp-infobox', __('Info Box', 'wpinfobox'), array(&$this, 'insert_form'), 'post', 'normal');	
		}
		
		// Form for infobox input
		public function insert_form($post) {
			$title = get_post_meta($post->ID, 'wpinfobox_title', true);
			$lead = get_post_meta($post->ID, 'wpinfobox_lead', true);
			for ($i=1; $i <= $this->max_items; $i++) { 
				$item[$i-1] = get_post_meta($post->ID, 'wpinfobox_item_' . $i, true);
			}
			$copy = get_post_meta($post->ID, 'wpinfobox_copy', true);
			?>
			<table class="form-table">
			<tr valign="top">
				<td><label for="wpinfobox_title"><?php _e("Title:", 'wpinfobox')?></label></td>
				<td>
					<input type="text" size="40" style="width:45%;" 
							name="wpinfobox_title" id="wpinfobox_title" 
							value="<?php echo $title; ?>" />
				</td>
			</tr>
			<tr valign="top">
				<td><label for="wpinfobox_lead"><?php _e("Lead:", 'wpinfobox')?></label></td>
				<td>
					<input type="text" size="40" style="width:45%;" 
							name="wpinfobox_lead" id="wpinfobox_lead" 
							value="<?php echo $lead; ?>" />
				</td>
			</tr>
			<?php
			for ($i=1; $i <= $this->max_items; $i++) { 
				?>
				<tr valign="top">
					<td><label for="wpinfobox_item_<?php echo $i?>"><?php echo __("Item", 'wpinfobox') .' '. $i . ':';?></label></td>
					<td>
						<input type="text" size="40" style="width:45%;" 
								name="wpinfobox_item_<?php echo $i?>" id="wpinfobox_item_<?php echo $i?>" 
								value="<?php echo $item[$i-1]; ?>" />
					</td>
				</tr>
				<?php
			}
			?>
			<tr valign="top">
				<td><label for="wpinfobox_copy"><?php _e("Copy:", 'wpinfobox')?></label></td>
				<td>
					<input type="text" size="40" style="width:45%;" 
							name="wpinfobox_copy" id="wpinfobox_copy" 
							value="<?php echo $copy; ?>" />
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<?php _e("Add an info box to the current post", "wpinfobox")?>
				</td>
			</tr>
			</table>
			<?php
		}
		
		// Set or unset custom fields
		protected function update_meta($id, $key, $val) {
			if (!empty($val)) {
				update_post_meta($id, $key, $val);
			} else {
				delete_post_meta($id, $key);
			}
		}
		
		// Save settings
		function add_meta_data($post_ID) {
			// don't let autosave eat up our custom fields
			if ( wp_is_post_revision( $post_ID ) or wp_is_post_autosave( $post_ID ) )
				return;
				
			$this->update_meta($post_ID, 'wpinfobox_title', $_POST['wpinfobox_title']);
			$this->update_meta($post_ID, 'wpinfobox_lead', $_POST['wpinfobox_lead']);
			for ($i=1; $i <= $this->max_items; $i++) {
				$this->update_meta($post_ID, 'wpinfobox_item_' . $i, $_POST['wpinfobox_item_' . $i]);
			}
			$this->update_meta($post_ID, 'wpinfobox_copy', $_POST['wpinfobox_copy']);
		}
		
		// Invoked from theme, this is the actual info box rendered
		public function the_box() {
			global $post;
			$title = get_post_meta($post->ID, 'wpinfobox_title', true);
			
			// Only display infox on single pages
			// TODO: Set this as an option
			if (is_single() && !empty($title)) {
				$lead = get_post_meta($post->ID, 'wpinfobox_lead', true);
				for ($i=1; $i <= $this->max_items; $i++) {
					$item[$i-1] = get_post_meta($post->ID, 'wpinfobox_item_' . $i, true);
				}
				$title = get_post_meta($post->ID, 'wpinfobox_title', true);
				$copy = get_post_meta($post->ID, 'wpinfobox_copy', true);
				?>
					<div class="wpinfobox">
						<h2><?php echo get_post_meta($post->ID, 'wpinfobox_title', true)?></h2>
						<div>
						<?php
						if (!empty($lead)) {
							echo "<p>" . $lead . "</p>";
						}
						if (!empty($item[0])) {
							echo "<ul>";
							foreach ($item as $tip) {
								if (!empty($tip)) {
									echo "<li>" . $tip . "</li>";
								}
							}
							echo "</ul>";
						}
						if (!empty($copy)) {
							echo "<p>" . $copy . "</p>";
						}
						?>
						</div>
					</div>
					<?php
			} else return "";
		}
		
		// Add infobox to content
		function content_filter($content)
		{
			return $this->the_box() . $content . '<div style="clear:both"></div>';
		}
	}
}

// Init class
if (class_exists("WPInfobox")) {
	$wpinfobox = new WPInfobox();
}

// Hooks, Actions and Filters, oh my!
add_action( 'init', array(&$wpinfobox, 'init_wpinfobox'));
add_action( 'admin_menu', array(&$wpinfobox, 'add_meta_box' )); 
add_action( 'save_post', array(&$wpinfobox, 'add_meta_data'));
add_filter( 'the_content', array (&$wpinfobox, 'content_filter'));
?>
